"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ActivitySeasonStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ActivitySeasonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ActivitySeasonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    StatusNone: _ActivitySeasonStatus.ValueType  # 0
    """"""
    StatusLive: _ActivitySeasonStatus.ValueType  # 1
    """"""
    StatusView: _ActivitySeasonStatus.ValueType  # 2
    """"""

class ActivitySeasonStatus(_ActivitySeasonStatus, metaclass=_ActivitySeasonStatusEnumTypeWrapper):
    """"""

StatusNone: ActivitySeasonStatus.ValueType  # 0
""""""
StatusLive: ActivitySeasonStatus.ValueType  # 1
""""""
StatusView: ActivitySeasonStatus.ValueType  # 2
""""""
global___ActivitySeasonStatus = ActivitySeasonStatus

class _OrderType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OrderTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TypeNone: _OrderType.ValueType  # 0
    """"""
    TypeOrderActivity: _OrderType.ValueType  # 1
    """"""
    TypeFavSeason: _OrderType.ValueType  # 2
    """"""
    TypeClick: _OrderType.ValueType  # 3
    """"""

class OrderType(_OrderType, metaclass=_OrderTypeEnumTypeWrapper):
    """"""

TypeNone: OrderType.ValueType  # 0
""""""
TypeOrderActivity: OrderType.ValueType  # 1
""""""
TypeFavSeason: OrderType.ValueType  # 2
""""""
TypeClick: OrderType.ValueType  # 3
""""""
global___OrderType = OrderType

class _ReplyEmoteMetaSize:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReplyEmoteMetaSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReplyEmoteMetaSize.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EMOTE_META_SIZE_UNSPECIFIED: _ReplyEmoteMetaSize.ValueType  # 0
    """"""
    EMOTE_META_SIZE_SMALL: _ReplyEmoteMetaSize.ValueType  # 1
    """"""
    EMOTE_META_SIZE_BIG: _ReplyEmoteMetaSize.ValueType  # 2
    """"""

class ReplyEmoteMetaSize(_ReplyEmoteMetaSize, metaclass=_ReplyEmoteMetaSizeEnumTypeWrapper):
    """"""

EMOTE_META_SIZE_UNSPECIFIED: ReplyEmoteMetaSize.ValueType  # 0
""""""
EMOTE_META_SIZE_SMALL: ReplyEmoteMetaSize.ValueType  # 1
""""""
EMOTE_META_SIZE_BIG: ReplyEmoteMetaSize.ValueType  # 2
""""""
global___ReplyEmoteMetaSize = ReplyEmoteMetaSize

@typing_extensions.final
class AccInfo(google.protobuf.message.Message):
    """用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户UID"""
    name: builtins.str
    """用户昵称"""
    sex: builtins.str
    """"""
    face: builtins.str
    """"""
    sign: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        face: builtins.str = ...,
        sign: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid", "name", b"name", "sex", b"sex", "sign", b"sign"]) -> None: ...

global___AccInfo = AccInfo

@typing_extensions.final
class AccountCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SPACESTA_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    LEVEL_INFO_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    FRIEND_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    mid: builtins.str
    """"""
    name: builtins.str
    """"""
    sex: builtins.str
    """"""
    rank: builtins.str
    """"""
    face: builtins.str
    """"""
    spacesta: builtins.int
    """"""
    sign: builtins.str
    """"""
    @property
    def level_info(self) -> global___CardLevelInfo:
        """"""
    @property
    def pendant(self) -> global___PendantInfo:
        """"""
    @property
    def nameplate(self) -> global___NameplateInfo:
        """"""
    @property
    def official(self) -> global___OfficialInfo:
        """"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
    @property
    def vip(self) -> global___CardVip:
        """"""
    fans: builtins.int
    """"""
    friend: builtins.int
    """"""
    attention: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.str = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        rank: builtins.str = ...,
        face: builtins.str = ...,
        spacesta: builtins.int = ...,
        sign: builtins.str = ...,
        level_info: global___CardLevelInfo | None = ...,
        pendant: global___PendantInfo | None = ...,
        nameplate: global___NameplateInfo | None = ...,
        official: global___OfficialInfo | None = ...,
        official_verify: global___OfficialVerify | None = ...,
        vip: global___CardVip | None = ...,
        fans: builtins.int = ...,
        friend: builtins.int = ...,
        attention: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["level_info", b"level_info", "nameplate", b"nameplate", "official", b"official", "official_verify", b"official_verify", "pendant", b"pendant", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "face", b"face", "fans", b"fans", "friend", b"friend", "level_info", b"level_info", "mid", b"mid", "name", b"name", "nameplate", b"nameplate", "official", b"official", "official_verify", b"official_verify", "pendant", b"pendant", "rank", b"rank", "sex", b"sex", "sign", b"sign", "spacesta", b"spacesta", "vip", b"vip"]) -> None: ...

global___AccountCard = AccountCard

@typing_extensions.final
class ActivityArchiveReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    RIGHT_RELATE_FIELD_NUMBER: builtins.int
    BOTTOM_RELATE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
    bvid: builtins.str
    """"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
    @property
    def req_user(self) -> global___ReqUser:
        """"""
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
    @property
    def right_relate(self) -> global___OperationRelate:
        """"""
    @property
    def bottom_relate(self) -> global___OperationRelate:
        """"""
    def __init__(
        self,
        *,
        arc: global___Arc | None = ...,
        bvid: builtins.str = ...,
        pages: collections.abc.Iterable[global___Page] | None = ...,
        req_user: global___ReqUser | None = ...,
        staff: collections.abc.Iterable[global___Staff] | None = ...,
        right_relate: global___OperationRelate | None = ...,
        bottom_relate: global___OperationRelate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "bottom_relate", b"bottom_relate", "req_user", b"req_user", "right_relate", b"right_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "bottom_relate", b"bottom_relate", "bvid", b"bvid", "pages", b"pages", "req_user", b"req_user", "right_relate", b"right_relate", "staff", b"staff"]) -> None: ...

global___ActivityArchiveReply = ActivityArchiveReply

@typing_extensions.final
class ActivityArchiveReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    activity_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        activity_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key", b"activity_key", "aid", b"aid", "bvid", b"bvid"]) -> None: ...

global___ActivityArchiveReq = ActivityArchiveReq

@typing_extensions.final
class ActivityEpisode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    cid: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def author(self) -> global___Author:
        """"""
    @property
    def rights(self) -> global___Rights:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        cid: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        author: global___Author | None = ...,
        rights: global___Rights | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "rights", b"rights"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "bvid", b"bvid", "cid", b"cid", "cover", b"cover", "id", b"id", "rights", b"rights", "title", b"title"]) -> None: ...

global___ActivityEpisode = ActivityEpisode

@typing_extensions.final
class ActivityGame(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IFRAMES_FIELD_NUMBER: builtins.int
    DISCLAIMER_FIELD_NUMBER: builtins.int
    DISCLAIMER_URL_FIELD_NUMBER: builtins.int
    @property
    def iframes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivityGameIframe]:
        """"""
    disclaimer: builtins.str
    """"""
    disclaimer_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        iframes: collections.abc.Iterable[global___ActivityGameIframe] | None = ...,
        disclaimer: builtins.str = ...,
        disclaimer_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disclaimer", b"disclaimer", "disclaimer_url", b"disclaimer_url", "iframes", b"iframes"]) -> None: ...

global___ActivityGame = ActivityGame

@typing_extensions.final
class ActivityGameIframe(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    height: builtins.int
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "url", b"url"]) -> None: ...

global___ActivityGameIframe = ActivityGameIframe

@typing_extensions.final
class ActivityLive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    NOW_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    HOVER_PIC_FIELD_NUMBER: builtins.int
    HOVER_JUMP_URL_FIELD_NUMBER: builtins.int
    BREAK_CYCLE_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    OPERATION_RELATE_FIELD_NUMBER: builtins.int
    REPLY_TYPE_FIELD_NUMBER: builtins.int
    REPLY_ID_FIELD_NUMBER: builtins.int
    HOVER_PIC_CLOSE_FIELD_NUMBER: builtins.int
    GIFT_DISCLAIMER_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """"""
    now_time: builtins.int
    """"""
    start_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    hover_pic: builtins.str
    """"""
    hover_jump_url: builtins.str
    """"""
    break_cycle: builtins.int
    """"""
    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LiveTimeline]:
        """"""
    @property
    def operation_relate(self) -> global___OperationRelate:
        """"""
    reply_type: builtins.int
    """"""
    reply_id: builtins.int
    """"""
    hover_pic_close: builtins.str
    """"""
    gift_disclaimer: builtins.str
    """"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        now_time: builtins.int = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        hover_pic: builtins.str = ...,
        hover_jump_url: builtins.str = ...,
        break_cycle: builtins.int = ...,
        timeline: collections.abc.Iterable[global___LiveTimeline] | None = ...,
        operation_relate: global___OperationRelate | None = ...,
        reply_type: builtins.int = ...,
        reply_id: builtins.int = ...,
        hover_pic_close: builtins.str = ...,
        gift_disclaimer: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_relate", b"operation_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["break_cycle", b"break_cycle", "end_time", b"end_time", "gift_disclaimer", b"gift_disclaimer", "hover_jump_url", b"hover_jump_url", "hover_pic", b"hover_pic", "hover_pic_close", b"hover_pic_close", "now_time", b"now_time", "operation_relate", b"operation_relate", "reply_id", b"reply_id", "reply_type", b"reply_type", "room_id", b"room_id", "start_time", b"start_time", "timeline", b"timeline"]) -> None: ...

global___ActivityLive = ActivityLive

@typing_extensions.final
class ActivityLiveTimeInfoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOW_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    now_time: builtins.int
    """"""
    start_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LiveTimeline]:
        """"""
    def __init__(
        self,
        *,
        now_time: builtins.int = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        timeline: collections.abc.Iterable[global___LiveTimeline] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "now_time", b"now_time", "start_time", b"start_time", "timeline", b"timeline"]) -> None: ...

global___ActivityLiveTimeInfoReply = ActivityLiveTimeInfoReply

@typing_extensions.final
class ActivityLiveTimeInfoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    activity_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key", b"activity_key"]) -> None: ...

global___ActivityLiveTimeInfoReq = ActivityLiveTimeInfoReq

@typing_extensions.final
class ActivitySeasonReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    SUBSCRIBE_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    THEME_FIELD_NUMBER: builtins.int
    status: global___ActivitySeasonStatus.ValueType
    """"""
    title: builtins.str
    """"""
    @property
    def live(self) -> global___ActivityLive:
        """"""
    @property
    def subscribe(self) -> global___ActivitySubscribe:
        """"""
    @property
    def game(self) -> global___ActivityGame:
        """"""
    @property
    def view(self) -> global___ActivityView:
        """"""
    @property
    def theme(self) -> global___ActivityTheme:
        """"""
    def __init__(
        self,
        *,
        status: global___ActivitySeasonStatus.ValueType = ...,
        title: builtins.str = ...,
        live: global___ActivityLive | None = ...,
        subscribe: global___ActivitySubscribe | None = ...,
        game: global___ActivityGame | None = ...,
        view: global___ActivityView | None = ...,
        theme: global___ActivityTheme | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["game", b"game", "live", b"live", "subscribe", b"subscribe", "theme", b"theme", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["game", b"game", "live", b"live", "status", b"status", "subscribe", b"subscribe", "theme", b"theme", "title", b"title", "view", b"view"]) -> None: ...

global___ActivitySeasonReply = ActivitySeasonReply

@typing_extensions.final
class ActivitySeasonReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    activity_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        activity_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key", b"activity_key", "aid", b"aid", "bvid", b"bvid"]) -> None: ...

global___ActivitySeasonReq = ActivitySeasonReq

@typing_extensions.final
class ActivitySeasonSection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    type: builtins.int
    """"""
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivityEpisode]:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        type: builtins.int = ...,
        episodes: collections.abc.Iterable[global___ActivityEpisode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes", b"episodes", "id", b"id", "title", b"title", "type", b"type"]) -> None: ...

global___ActivitySeasonSection = ActivitySeasonSection

@typing_extensions.final
class ActivitySubscribe(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SEASON_STAT_VIEW_FIELD_NUMBER: builtins.int
    SEASON_STAT_DANMAKU_FIELD_NUMBER: builtins.int
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_ACTIVITY_PARAM_FIELD_NUMBER: builtins.int
    FAV_SEASON_PARAM_FIELD_NUMBER: builtins.int
    JUMP_URL_PARAM_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """"""
    title: builtins.str
    """"""
    button_title: builtins.str
    """"""
    button_selected_title: builtins.str
    """"""
    season_stat_view: builtins.int
    """"""
    season_stat_danmaku: builtins.int
    """"""
    order_type: global___OrderType.ValueType
    """"""
    @property
    def reserve_activity_param(self) -> global___ReserveActivityParam:
        """"""
    @property
    def fav_season_param(self) -> global___FavSeasonParam:
        """"""
    @property
    def jump_URL_param(self) -> global___JumpURLParam:
        """"""
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
        title: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        season_stat_view: builtins.int = ...,
        season_stat_danmaku: builtins.int = ...,
        order_type: global___OrderType.ValueType = ...,
        reserve_activity_param: global___ReserveActivityParam | None = ...,
        fav_season_param: global___FavSeasonParam | None = ...,
        jump_URL_param: global___JumpURLParam | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season_param", b"fav_season_param", "jump_URL_param", b"jump_URL_param", "param", b"param", "reserve_activity_param", b"reserve_activity_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "fav_season_param", b"fav_season_param", "jump_URL_param", b"jump_URL_param", "order_type", b"order_type", "param", b"param", "reserve_activity_param", b"reserve_activity_param", "season_stat_danmaku", b"season_stat_danmaku", "season_stat_view", b"season_stat_view", "status", b"status", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param", b"param"]) -> typing_extensions.Literal["reserve_activity_param", "fav_season_param", "jump_URL_param"] | None: ...

global___ActivitySubscribe = ActivitySubscribe

@typing_extensions.final
class ActivityTheme(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class KvColorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BASE_COLOR_FIELD_NUMBER: builtins.int
    LOADING_BG_COLOR_FIELD_NUMBER: builtins.int
    OPERATED_BG_COLOR_FIELD_NUMBER: builtins.int
    DEFAULT_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    HOVER_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    BASE_FONT_COLOR_FIELD_NUMBER: builtins.int
    INFO_FONT_COLOR_FIELD_NUMBER: builtins.int
    MASK_BG_COLOR_FIELD_NUMBER: builtins.int
    PAGE_BG_COLOR_FIELD_NUMBER: builtins.int
    CENTER_LOGO_IMG_FIELD_NUMBER: builtins.int
    PAGE_BG_IMG_FIELD_NUMBER: builtins.int
    DECORATIONS2233_IMG_FIELD_NUMBER: builtins.int
    MAIN_BANNER_BG_IMG_FIELD_NUMBER: builtins.int
    MAIN_BANNER_TITLE_IMG_FIELD_NUMBER: builtins.int
    LIKE_ANIMATION_IMG_FIELD_NUMBER: builtins.int
    COMBO_LIKE_IMG_FIELD_NUMBER: builtins.int
    COMBO_COIN_IMG_FIELD_NUMBER: builtins.int
    COMBO_FAV_IMG_FIELD_NUMBER: builtins.int
    ARROW_BTN_IMG_FIELD_NUMBER: builtins.int
    SHARE_ICON_BG_IMG_FIELD_NUMBER: builtins.int
    LIVE_LIST_LOCATION_IMG_FIELD_NUMBER: builtins.int
    LIVE_LIST_LOCATION_IMG_ACTIVE_FIELD_NUMBER: builtins.int
    PLAYER_LOADING_IMG_FIELD_NUMBER: builtins.int
    SHARE_IMG_FIELD_NUMBER: builtins.int
    KV_COLOR_FIELD_NUMBER: builtins.int
    base_color: builtins.str
    """"""
    loading_bg_color: builtins.str
    """"""
    operated_bg_color: builtins.str
    """"""
    default_element_color: builtins.str
    """"""
    hover_element_color: builtins.str
    """"""
    selected_element_color: builtins.str
    """"""
    base_font_color: builtins.str
    """"""
    info_font_color: builtins.str
    """"""
    mask_bg_color: builtins.str
    """"""
    page_bg_color: builtins.str
    """"""
    center_logo_img: builtins.str
    """"""
    page_bg_img: builtins.str
    """"""
    decorations2233_img: builtins.str
    """"""
    main_banner_bg_img: builtins.str
    """"""
    main_banner_title_img: builtins.str
    """"""
    like_animation_img: builtins.str
    """"""
    combo_like_img: builtins.str
    """"""
    combo_coin_img: builtins.str
    """"""
    combo_fav_img: builtins.str
    """"""
    arrow_btn_img: builtins.str
    """"""
    share_icon_bg_img: builtins.str
    """"""
    live_list_location_img: builtins.str
    """"""
    live_list_location_img_active: builtins.str
    """"""
    player_loading_img: builtins.str
    """"""
    share_img: builtins.str
    """"""
    @property
    def kv_color(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        base_color: builtins.str = ...,
        loading_bg_color: builtins.str = ...,
        operated_bg_color: builtins.str = ...,
        default_element_color: builtins.str = ...,
        hover_element_color: builtins.str = ...,
        selected_element_color: builtins.str = ...,
        base_font_color: builtins.str = ...,
        info_font_color: builtins.str = ...,
        mask_bg_color: builtins.str = ...,
        page_bg_color: builtins.str = ...,
        center_logo_img: builtins.str = ...,
        page_bg_img: builtins.str = ...,
        decorations2233_img: builtins.str = ...,
        main_banner_bg_img: builtins.str = ...,
        main_banner_title_img: builtins.str = ...,
        like_animation_img: builtins.str = ...,
        combo_like_img: builtins.str = ...,
        combo_coin_img: builtins.str = ...,
        combo_fav_img: builtins.str = ...,
        arrow_btn_img: builtins.str = ...,
        share_icon_bg_img: builtins.str = ...,
        live_list_location_img: builtins.str = ...,
        live_list_location_img_active: builtins.str = ...,
        player_loading_img: builtins.str = ...,
        share_img: builtins.str = ...,
        kv_color: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arrow_btn_img", b"arrow_btn_img", "base_color", b"base_color", "base_font_color", b"base_font_color", "center_logo_img", b"center_logo_img", "combo_coin_img", b"combo_coin_img", "combo_fav_img", b"combo_fav_img", "combo_like_img", b"combo_like_img", "decorations2233_img", b"decorations2233_img", "default_element_color", b"default_element_color", "hover_element_color", b"hover_element_color", "info_font_color", b"info_font_color", "kv_color", b"kv_color", "like_animation_img", b"like_animation_img", "live_list_location_img", b"live_list_location_img", "live_list_location_img_active", b"live_list_location_img_active", "loading_bg_color", b"loading_bg_color", "main_banner_bg_img", b"main_banner_bg_img", "main_banner_title_img", b"main_banner_title_img", "mask_bg_color", b"mask_bg_color", "operated_bg_color", b"operated_bg_color", "page_bg_color", b"page_bg_color", "page_bg_img", b"page_bg_img", "player_loading_img", b"player_loading_img", "selected_element_color", b"selected_element_color", "share_icon_bg_img", b"share_icon_bg_img", "share_img", b"share_img"]) -> None: ...

global___ActivityTheme = ActivityTheme

@typing_extensions.final
class ActivityView(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    RIGHT_RELATE_FIELD_NUMBER: builtins.int
    BOTTOM_RELATE_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
    bvid: builtins.str
    """"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
    @property
    def req_user(self) -> global___ReqUser:
        """"""
    @property
    def right_relate(self) -> global___OperationRelate:
        """"""
    @property
    def bottom_relate(self) -> global___OperationRelate:
        """"""
    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivitySeasonSection]:
        """"""
    def __init__(
        self,
        *,
        arc: global___Arc | None = ...,
        bvid: builtins.str = ...,
        pages: collections.abc.Iterable[global___Page] | None = ...,
        staff: collections.abc.Iterable[global___Staff] | None = ...,
        req_user: global___ReqUser | None = ...,
        right_relate: global___OperationRelate | None = ...,
        bottom_relate: global___OperationRelate | None = ...,
        sections: collections.abc.Iterable[global___ActivitySeasonSection] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "bottom_relate", b"bottom_relate", "req_user", b"req_user", "right_relate", b"right_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "bottom_relate", b"bottom_relate", "bvid", b"bvid", "pages", b"pages", "req_user", b"req_user", "right_relate", b"right_relate", "sections", b"sections", "staff", b"staff"]) -> None: ...

global___ActivityView = ActivityView

@typing_extensions.final
class Arc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PUBDATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FORWARD_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    REPORT_RESULT_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    FIRST_CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    STAFF_INFO_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    IS_CHARGEABLE_SEASON_FIELD_NUMBER: builtins.int
    IS_BLOOPER_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    videos: builtins.int
    """"""
    type_id: builtins.int
    """"""
    type_name: builtins.str
    """"""
    copyright: builtins.int
    """"""
    pic: builtins.str
    """"""
    title: builtins.str
    """"""
    pubdate: builtins.int
    """"""
    ctime: builtins.int
    """"""
    desc: builtins.str
    """"""
    state: builtins.int
    """"""
    access: builtins.int
    """"""
    attribute: builtins.int
    """"""
    tag: builtins.str
    """"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    duration: builtins.int
    """"""
    mission_id: builtins.int
    """"""
    order_id: builtins.int
    """"""
    redirect_url: builtins.str
    """"""
    forward: builtins.int
    """"""
    @property
    def rights(self) -> global___Rights:
        """"""
    @property
    def author(self) -> global___Author:
        """"""
    @property
    def stat(self) -> global___Stat:
        """"""
    report_result: builtins.str
    """"""
    dynamic: builtins.str
    """"""
    first_cid: builtins.int
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """"""
    @property
    def staff_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaffInfo]:
        """"""
    season_id: builtins.int
    """"""
    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """"""
    is_chargeable_season: builtins.bool
    """"""
    is_blooper: builtins.bool
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        videos: builtins.int = ...,
        type_id: builtins.int = ...,
        type_name: builtins.str = ...,
        copyright: builtins.int = ...,
        pic: builtins.str = ...,
        title: builtins.str = ...,
        pubdate: builtins.int = ...,
        ctime: builtins.int = ...,
        desc: builtins.str = ...,
        state: builtins.int = ...,
        access: builtins.int = ...,
        attribute: builtins.int = ...,
        tag: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        duration: builtins.int = ...,
        mission_id: builtins.int = ...,
        order_id: builtins.int = ...,
        redirect_url: builtins.str = ...,
        forward: builtins.int = ...,
        rights: global___Rights | None = ...,
        author: global___Author | None = ...,
        stat: global___Stat | None = ...,
        report_result: builtins.str = ...,
        dynamic: builtins.str = ...,
        first_cid: builtins.int = ...,
        dimension: global___Dimension | None = ...,
        staff_info: collections.abc.Iterable[global___StaffInfo] | None = ...,
        season_id: builtins.int = ...,
        desc_v2: collections.abc.Iterable[global___DescV2] | None = ...,
        is_chargeable_season: builtins.bool = ...,
        is_blooper: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "dimension", b"dimension", "rights", b"rights", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "aid", b"aid", "attribute", b"attribute", "author", b"author", "copyright", b"copyright", "ctime", b"ctime", "desc", b"desc", "desc_v2", b"desc_v2", "dimension", b"dimension", "duration", b"duration", "dynamic", b"dynamic", "first_cid", b"first_cid", "forward", b"forward", "is_blooper", b"is_blooper", "is_chargeable_season", b"is_chargeable_season", "mission_id", b"mission_id", "order_id", b"order_id", "pic", b"pic", "pubdate", b"pubdate", "redirect_url", b"redirect_url", "report_result", b"report_result", "rights", b"rights", "season_id", b"season_id", "staff_info", b"staff_info", "stat", b"stat", "state", b"state", "tag", b"tag", "tags", b"tags", "title", b"title", "type_id", b"type_id", "type_name", b"type_name", "videos", b"videos"]) -> None: ...

global___Arc = Arc

@typing_extensions.final
class Author(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    face: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid", "name", b"name"]) -> None: ...

global___Author = Author

@typing_extensions.final
class Card(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_FIELD_NUMBER: builtins.int
    SPACE_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    ARCHIVE_COUNT_FIELD_NUMBER: builtins.int
    ARTICLE_COUNT_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    @property
    def card(self) -> global___AccountCard:
        """"""
    @property
    def space(self) -> global___Space:
        """"""
    following: builtins.bool
    """"""
    archive_count: builtins.int
    """"""
    article_count: builtins.int
    """"""
    follower: builtins.int
    """"""
    def __init__(
        self,
        *,
        card: global___AccountCard | None = ...,
        space: global___Space | None = ...,
        following: builtins.bool = ...,
        archive_count: builtins.int = ...,
        article_count: builtins.int = ...,
        follower: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card", b"card", "space", b"space"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_count", b"archive_count", "article_count", b"article_count", "card", b"card", "follower", b"follower", "following", b"following", "space", b"space"]) -> None: ...

global___Card = Card

@typing_extensions.final
class CardLevelInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUR_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    NOW_EXP_FIELD_NUMBER: builtins.int
    NEXT_EXP_FIELD_NUMBER: builtins.int
    cur: builtins.int
    """"""
    min: builtins.int
    """"""
    now_exp: builtins.int
    """"""
    next_exp: builtins.int
    """"""
    def __init__(
        self,
        *,
        cur: builtins.int = ...,
        min: builtins.int = ...,
        now_exp: builtins.int = ...,
        next_exp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur", b"cur", "min", b"min", "next_exp", b"next_exp", "now_exp", b"now_exp"]) -> None: ...

global___CardLevelInfo = CardLevelInfo

@typing_extensions.final
class CardVip(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    due_remark: builtins.str
    """"""
    access_status: builtins.int
    """"""
    vip_status: builtins.int
    """"""
    vip_status_warn: builtins.str
    """"""
    theme_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        due_remark: builtins.str = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: builtins.str = ...,
        theme_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status", b"access_status", "due_remark", b"due_remark", "theme_type", b"theme_type", "type", b"type", "vip_status", b"vip_status", "vip_status_warn", b"vip_status_warn"]) -> None: ...

global___CardVip = CardVip

@typing_extensions.final
class ClickActivitySeasonReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_ACTIVITY_PARAM_FIELD_NUMBER: builtins.int
    FAV_SEASON_PARAM_FIELD_NUMBER: builtins.int
    JUMP_URL_PARAM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    order_type: global___OrderType.ValueType
    """"""
    @property
    def reserve_activity_param(self) -> global___ReserveActivityParam:
        """"""
    @property
    def fav_season_param(self) -> global___FavSeasonParam:
        """"""
    @property
    def jump_URL_param(self) -> global___JumpURLParam:
        """"""
    spmid: builtins.str
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        order_type: global___OrderType.ValueType = ...,
        reserve_activity_param: global___ReserveActivityParam | None = ...,
        fav_season_param: global___FavSeasonParam | None = ...,
        jump_URL_param: global___JumpURLParam | None = ...,
        spmid: builtins.str = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season_param", b"fav_season_param", "jump_URL_param", b"jump_URL_param", "param", b"param", "reserve_activity_param", b"reserve_activity_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "fav_season_param", b"fav_season_param", "jump_URL_param", b"jump_URL_param", "order_type", b"order_type", "param", b"param", "reserve_activity_param", b"reserve_activity_param", "spmid", b"spmid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param", b"param"]) -> typing_extensions.Literal["reserve_activity_param", "fav_season_param", "jump_URL_param"] | None: ...

global___ClickActivitySeasonReq = ClickActivitySeasonReq

@typing_extensions.final
class DescV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    raw_text: builtins.str
    """"""
    type: builtins.int
    """"""
    biz_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        raw_text: builtins.str = ...,
        type: builtins.int = ...,
        biz_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "raw_text", b"raw_text", "type", b"type"]) -> None: ...

global___DescV2 = DescV2

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    rotate: builtins.int
    """"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class FavSeasonParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___FavSeasonParam = FavSeasonParam

@typing_extensions.final
class HotReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    @property
    def page(self) -> global___ReplyPage:
        """"""
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Reply]:
        """"""
    def __init__(
        self,
        *,
        page: global___ReplyPage | None = ...,
        replies: collections.abc.Iterable[global___Reply] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["page", b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "replies", b"replies"]) -> None: ...

global___HotReply = HotReply

@typing_extensions.final
class JumpURLParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JUMP_URL_FIELD_NUMBER: builtins.int
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url"]) -> None: ...

global___JumpURLParam = JumpURLParam

@typing_extensions.final
class LiveTimeline(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    H5_COVER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    start_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    cover: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    h5_cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        cover: builtins.str = ...,
        subtitle: builtins.str = ...,
        h5_cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "end_time", b"end_time", "h5_cover", b"h5_cover", "name", b"name", "start_time", b"start_time", "subtitle", b"subtitle"]) -> None: ...

global___LiveTimeline = LiveTimeline

@typing_extensions.final
class NameplateInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_SMALL_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    nid: builtins.int
    """"""
    name: builtins.str
    """"""
    image: builtins.str
    """"""
    image_small: builtins.str
    """"""
    level: builtins.str
    """"""
    condition: builtins.str
    """"""
    def __init__(
        self,
        *,
        nid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        image_small: builtins.str = ...,
        level: builtins.str = ...,
        condition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "image", b"image", "image_small", b"image_small", "level", b"level", "name", b"name", "nid", b"nid"]) -> None: ...

global___NameplateInfo = NameplateInfo

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class OfficialInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    role: builtins.int
    """"""
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        role: builtins.int = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "role", b"role", "title", b"title"]) -> None: ...

global___OfficialInfo = OfficialInfo

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class OperationRelate(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    RELATE_ITEM_FIELD_NUMBER: builtins.int
    AI_RELATE_ITEM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateItem]:
        """"""
    @property
    def ai_relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        relate_item: collections.abc.Iterable[global___RelateItem] | None = ...,
        ai_relate_item: collections.abc.Iterable[global___Relate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_relate_item", b"ai_relate_item", "relate_item", b"relate_item", "title", b"title"]) -> None: ...

global___OperationRelate = OperationRelate

@typing_extensions.final
class Page(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    WEBLINK_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""
    page: builtins.int
    """"""
    part: builtins.str
    """"""
    duration: builtins.int
    """"""
    vid: builtins.str
    """"""
    desc: builtins.str
    """"""
    weblink: builtins.str
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        part: builtins.str = ...,
        duration: builtins.int = ...,
        vid: builtins.str = ...,
        desc: builtins.str = ...,
        weblink: builtins.str = ...,
        dimension: global___Dimension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "desc", b"desc", "dimension", b"dimension", "duration", b"duration", "from", b"from", "page", b"page", "part", b"part", "vid", b"vid", "weblink", b"weblink"]) -> None: ...

global___Page = Page

@typing_extensions.final
class PendantInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """"""
    name: builtins.str
    """"""
    image: builtins.str
    """"""
    expire: builtins.int
    """"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        expire: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire", b"expire", "image", b"image", "name", b"name", "pid", b"pid"]) -> None: ...

global___PendantInfo = PendantInfo

@typing_extensions.final
class ReasonStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___ReasonStyle = ReasonStyle

@typing_extensions.final
class Relate(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
    bvid: builtins.str
    """"""
    season_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        arc: global___Arc | None = ...,
        bvid: builtins.str = ...,
        season_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "bvid", b"bvid", "season_type", b"season_type"]) -> None: ...

global___Relate = Relate

@typing_extensions.final
class RelateItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "url", b"url"]) -> None: ...

global___RelateItem = RelateItem

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTRIBUTE_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    attribute: builtins.int
    """"""
    special: builtins.int
    """"""
    def __init__(
        self,
        *,
        attribute: builtins.int = ...,
        special: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "special", b"special"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class Reply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RPID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DIALOG_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    RCOUNT_FIELD_NUMBER: builtins.int
    FLOOR_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    FANS_GRADE_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    RPID_STR_FIELD_NUMBER: builtins.int
    ROOT_STR_FIELD_NUMBER: builtins.int
    PARENT_STR_FIELD_NUMBER: builtins.int
    DIALOG_STR_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    HATE_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    ASSIST_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    UP_ACTION_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    RAW_INPUT_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """"""
    oid: builtins.int
    """"""
    type: builtins.int
    """"""
    mid: builtins.int
    """"""
    root: builtins.int
    """"""
    parent: builtins.int
    """"""
    dialog: builtins.int
    """"""
    count: builtins.int
    """"""
    rcount: builtins.int
    """"""
    floor: builtins.int
    """"""
    state: builtins.int
    """"""
    fans_grade: builtins.int
    """"""
    attr: builtins.int
    """"""
    ctime: builtins.int
    """"""
    rpid_str: builtins.str
    """"""
    root_str: builtins.str
    """"""
    parent_str: builtins.str
    """"""
    dialog_str: builtins.str
    """"""
    like: builtins.int
    """"""
    hate: builtins.int
    """"""
    action: builtins.int
    """"""
    @property
    def member(self) -> global___ReplyMember:
        """"""
    @property
    def content(self) -> global___ReplyContent:
        """"""
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Reply]:
        """"""
    assist: builtins.int
    """"""
    @property
    def folder(self) -> global___ReplyFolder:
        """"""
    @property
    def up_action(self) -> global___ReplyUpAction:
        """"""
    @property
    def label(self) -> global___ReplyLabel:
        """"""
    raw_input: builtins.str
    """"""
    show_follow: builtins.bool
    """"""
    def __init__(
        self,
        *,
        rpid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        mid: builtins.int = ...,
        root: builtins.int = ...,
        parent: builtins.int = ...,
        dialog: builtins.int = ...,
        count: builtins.int = ...,
        rcount: builtins.int = ...,
        floor: builtins.int = ...,
        state: builtins.int = ...,
        fans_grade: builtins.int = ...,
        attr: builtins.int = ...,
        ctime: builtins.int = ...,
        rpid_str: builtins.str = ...,
        root_str: builtins.str = ...,
        parent_str: builtins.str = ...,
        dialog_str: builtins.str = ...,
        like: builtins.int = ...,
        hate: builtins.int = ...,
        action: builtins.int = ...,
        member: global___ReplyMember | None = ...,
        content: global___ReplyContent | None = ...,
        replies: collections.abc.Iterable[global___Reply] | None = ...,
        assist: builtins.int = ...,
        folder: global___ReplyFolder | None = ...,
        up_action: global___ReplyUpAction | None = ...,
        label: global___ReplyLabel | None = ...,
        raw_input: builtins.str = ...,
        show_follow: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "folder", b"folder", "label", b"label", "member", b"member", "up_action", b"up_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "assist", b"assist", "attr", b"attr", "content", b"content", "count", b"count", "ctime", b"ctime", "dialog", b"dialog", "dialog_str", b"dialog_str", "fans_grade", b"fans_grade", "floor", b"floor", "folder", b"folder", "hate", b"hate", "label", b"label", "like", b"like", "member", b"member", "mid", b"mid", "oid", b"oid", "parent", b"parent", "parent_str", b"parent_str", "raw_input", b"raw_input", "rcount", b"rcount", "replies", b"replies", "root", b"root", "root_str", b"root_str", "rpid", b"rpid", "rpid_str", b"rpid_str", "show_follow", b"show_follow", "state", b"state", "type", b"type", "up_action", b"up_action"]) -> None: ...

global___Reply = Reply

@typing_extensions.final
class ReplyContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EmoteEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___ReplyEmote: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___ReplyEmote | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RP_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    EMOTE_FIELD_NUMBER: builtins.int
    rp_id: builtins.int
    """"""
    message: builtins.str
    """"""
    @property
    def vote(self) -> global___ReplyVote:
        """"""
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    ip: builtins.int
    """"""
    plat: builtins.int
    """"""
    device: builtins.str
    """"""
    version: builtins.str
    """"""
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyMemberInfo]:
        """"""
    @property
    def emote(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___ReplyEmote]:
        """"""
    def __init__(
        self,
        *,
        rp_id: builtins.int = ...,
        message: builtins.str = ...,
        vote: global___ReplyVote | None = ...,
        topics: collections.abc.Iterable[builtins.str] | None = ...,
        ip: builtins.int = ...,
        plat: builtins.int = ...,
        device: builtins.str = ...,
        version: builtins.str = ...,
        members: collections.abc.Iterable[global___ReplyMemberInfo] | None = ...,
        emote: collections.abc.Mapping[builtins.str, global___ReplyEmote] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote", b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device", "emote", b"emote", "ip", b"ip", "members", b"members", "message", b"message", "plat", b"plat", "rp_id", b"rp_id", "topics", b"topics", "version", b"version", "vote", b"vote"]) -> None: ...

global___ReplyContent = ReplyContent

@typing_extensions.final
class ReplyEmote(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PACKAGE_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    package_id: builtins.int
    """"""
    state: builtins.int
    """"""
    type: builtins.int
    """"""
    attr: builtins.int
    """"""
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    @property
    def meta(self) -> global___ReplyEmoteMeta:
        """"""
    ctime: builtins.int
    """"""
    mtime: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        package_id: builtins.int = ...,
        state: builtins.int = ...,
        type: builtins.int = ...,
        attr: builtins.int = ...,
        text: builtins.str = ...,
        url: builtins.str = ...,
        meta: global___ReplyEmoteMeta | None = ...,
        ctime: builtins.int = ...,
        mtime: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attr", b"attr", "ctime", b"ctime", "id", b"id", "meta", b"meta", "mtime", b"mtime", "package_id", b"package_id", "state", b"state", "text", b"text", "type", b"type", "url", b"url"]) -> None: ...

global___ReplyEmote = ReplyEmote

@typing_extensions.final
class ReplyEmoteMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    size: global___ReplyEmoteMetaSize.ValueType
    """"""
    def __init__(
        self,
        *,
        size: global___ReplyEmoteMetaSize.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size", b"size"]) -> None: ...

global___ReplyEmoteMeta = ReplyEmoteMeta

@typing_extensions.final
class ReplyFansDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    MEDAL_ID_FIELD_NUMBER: builtins.int
    MEDAL_NAME_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INTIMACY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RECEIVED_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    medal_id: builtins.int
    """"""
    medal_name: builtins.str
    """"""
    score: builtins.int
    """"""
    level: builtins.int
    """"""
    intimacy: builtins.int
    """"""
    status: builtins.int
    """"""
    received: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        medal_id: builtins.int = ...,
        medal_name: builtins.str = ...,
        score: builtins.int = ...,
        level: builtins.int = ...,
        intimacy: builtins.int = ...,
        status: builtins.int = ...,
        received: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intimacy", b"intimacy", "level", b"level", "medal_id", b"medal_id", "medal_name", b"medal_name", "received", b"received", "score", b"score", "status", b"status", "uid", b"uid"]) -> None: ...

global___ReplyFansDetail = ReplyFansDetail

@typing_extensions.final
class ReplyFolder(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_FOLDED_FIELD_NUMBER: builtins.int
    IS_FOLDED_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    has_folded: builtins.bool
    """"""
    is_folded: builtins.bool
    """"""
    rule: builtins.str
    """"""
    def __init__(
        self,
        *,
        has_folded: builtins.bool = ...,
        is_folded: builtins.bool = ...,
        rule: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_folded", b"has_folded", "is_folded", b"is_folded", "rule", b"rule"]) -> None: ...

global___ReplyFolder = ReplyFolder

@typing_extensions.final
class ReplyLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RPID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_MODE_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_MODE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """"""
    content: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night_mode: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night_mode: builtins.str
    """"""
    link: builtins.str
    """"""
    position: builtins.str
    """"""
    def __init__(
        self,
        *,
        rpid: builtins.int = ...,
        content: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night_mode: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night_mode: builtins.str = ...,
        link: builtins.str = ...,
        position: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night_mode", b"bg_color_night_mode", "content", b"content", "link", b"link", "position", b"position", "rpid", b"rpid", "text_color", b"text_color", "text_color_night_mode", b"text_color_night_mode"]) -> None: ...

global___ReplyLabel = ReplyLabel

@typing_extensions.final
class ReplyLevelInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUR_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    NOW_EXP_FIELD_NUMBER: builtins.int
    NEXT_EXP_FIELD_NUMBER: builtins.int
    cur: builtins.int
    """"""
    min: builtins.int
    """"""
    now_exp: builtins.int
    """"""
    next_exp: builtins.int
    """"""
    def __init__(
        self,
        *,
        cur: builtins.int = ...,
        min: builtins.int = ...,
        now_exp: builtins.int = ...,
        next_exp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur", b"cur", "min", b"min", "next_exp", b"next_exp", "now_exp", b"now_exp"]) -> None: ...

global___ReplyLevelInfo = ReplyLevelInfo

@typing_extensions.final
class ReplyMember(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    FANS_DETAIL_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___ReplyMemberInfo:
        """"""
    @property
    def fans_detail(self) -> global___ReplyFansDetail:
        """"""
    following: builtins.int
    """"""
    def __init__(
        self,
        *,
        info: global___ReplyMemberInfo | None = ...,
        fans_detail: global___ReplyFansDetail | None = ...,
        following: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fans_detail", b"fans_detail", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fans_detail", b"fans_detail", "following", b"following", "info", b"info"]) -> None: ...

global___ReplyMember = ReplyMember

@typing_extensions.final
class ReplyMemberInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    DISPLAY_RANK_FIELD_NUMBER: builtins.int
    LEVEL_INFO_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    role: builtins.int
    """"""
    mid: builtins.str
    """"""
    name: builtins.str
    """"""
    sex: builtins.str
    """"""
    sign: builtins.str
    """"""
    avatar: builtins.str
    """"""
    rank: builtins.str
    """"""
    display_rank: builtins.str
    """"""
    @property
    def level_info(self) -> global___ReplyLevelInfo:
        """"""
    @property
    def pendant(self) -> global___PendantInfo:
        """"""
    @property
    def nameplate(self) -> global___NameplateInfo:
        """"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
    @property
    def vip(self) -> global___ReplyVip:
        """"""
    def __init__(
        self,
        *,
        role: builtins.int = ...,
        mid: builtins.str = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        sign: builtins.str = ...,
        avatar: builtins.str = ...,
        rank: builtins.str = ...,
        display_rank: builtins.str = ...,
        level_info: global___ReplyLevelInfo | None = ...,
        pendant: global___PendantInfo | None = ...,
        nameplate: global___NameplateInfo | None = ...,
        official_verify: global___OfficialVerify | None = ...,
        vip: global___ReplyVip | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["level_info", b"level_info", "nameplate", b"nameplate", "official_verify", b"official_verify", "pendant", b"pendant", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "display_rank", b"display_rank", "level_info", b"level_info", "mid", b"mid", "name", b"name", "nameplate", b"nameplate", "official_verify", b"official_verify", "pendant", b"pendant", "rank", b"rank", "role", b"role", "sex", b"sex", "sign", b"sign", "vip", b"vip"]) -> None: ...

global___ReplyMemberInfo = ReplyMemberInfo

@typing_extensions.final
class ReplyPage(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACOUNT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    acount: builtins.int
    """"""
    count: builtins.int
    """"""
    num: builtins.int
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        acount: builtins.int = ...,
        count: builtins.int = ...,
        num: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["acount", b"acount", "count", b"count", "num", b"num", "size", b"size"]) -> None: ...

global___ReplyPage = ReplyPage

@typing_extensions.final
class ReplyUpAction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    like: builtins.bool
    """"""
    reply: builtins.bool
    """"""
    def __init__(
        self,
        *,
        like: builtins.bool = ...,
        reply: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like", b"like", "reply", b"reply"]) -> None: ...

global___ReplyUpAction = ReplyUpAction

@typing_extensions.final
class ReplyVip(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    due_date: builtins.int
    """"""
    due_remark: builtins.str
    """"""
    access_status: builtins.int
    """"""
    vip_status: builtins.int
    """"""
    vip_status_warn: builtins.str
    """"""
    theme_type: builtins.int
    """"""
    @property
    def label(self) -> global___VipLabel:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        due_date: builtins.int = ...,
        due_remark: builtins.str = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: builtins.str = ...,
        theme_type: builtins.int = ...,
        label: global___VipLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status", b"access_status", "due_date", b"due_date", "due_remark", b"due_remark", "label", b"label", "theme_type", b"theme_type", "type", b"type", "vip_status", b"vip_status", "vip_status_warn", b"vip_status_warn"]) -> None: ...

global___ReplyVip = ReplyVip

@typing_extensions.final
class ReplyVote(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CNT_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    cnt: builtins.int
    """"""
    desc: builtins.str
    """"""
    deleted: builtins.bool
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        cnt: builtins.int = ...,
        desc: builtins.str = ...,
        deleted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cnt", b"cnt", "deleted", b"deleted", "desc", b"desc", "id", b"id", "title", b"title"]) -> None: ...

global___ReplyVote = ReplyVote

@typing_extensions.final
class ReqUser(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAVORITE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    MULTIPLY_FIELD_NUMBER: builtins.int
    favorite: builtins.bool
    """"""
    like: builtins.bool
    """"""
    dislike: builtins.bool
    """"""
    multiply: builtins.int
    """"""
    def __init__(
        self,
        *,
        favorite: builtins.bool = ...,
        like: builtins.bool = ...,
        dislike: builtins.bool = ...,
        multiply: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike", b"dislike", "favorite", b"favorite", "like", b"like", "multiply", b"multiply"]) -> None: ...

global___ReqUser = ReqUser

@typing_extensions.final
class ReserveActivityParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVE_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    reserve_id: builtins.int
    """"""
    type: builtins.str
    """"""
    oid: builtins.int
    """"""
    def __init__(
        self,
        *,
        reserve_id: builtins.int = ...,
        type: builtins.str = ...,
        oid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "oid", b"oid", "reserve_id", b"reserve_id", "type", b"type"]) -> None: ...

global___ReserveActivityParam = ReserveActivityParam

@typing_extensions.final
class Rights(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BP_FIELD_NUMBER: builtins.int
    ELEC_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    MOVIE_FIELD_NUMBER: builtins.int
    PAY_FIELD_NUMBER: builtins.int
    HD5_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    UGC_PAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    UGC_PAY_PREVIEW_FIELD_NUMBER: builtins.int
    ARC_PAY_FIELD_NUMBER: builtins.int
    FREE_WATCH_FIELD_NUMBER: builtins.int
    bp: builtins.int
    """"""
    elec: builtins.int
    """"""
    download: builtins.int
    """"""
    movie: builtins.int
    """"""
    pay: builtins.int
    """"""
    hd5: builtins.int
    """"""
    no_reprint: builtins.int
    """"""
    autoplay: builtins.int
    """"""
    ugc_pay: builtins.int
    """"""
    is_cooperation: builtins.int
    """"""
    ugc_pay_preview: builtins.int
    """"""
    arc_pay: builtins.int
    """"""
    free_watch: builtins.int
    """"""
    def __init__(
        self,
        *,
        bp: builtins.int = ...,
        elec: builtins.int = ...,
        download: builtins.int = ...,
        movie: builtins.int = ...,
        pay: builtins.int = ...,
        hd5: builtins.int = ...,
        no_reprint: builtins.int = ...,
        autoplay: builtins.int = ...,
        ugc_pay: builtins.int = ...,
        is_cooperation: builtins.int = ...,
        ugc_pay_preview: builtins.int = ...,
        arc_pay: builtins.int = ...,
        free_watch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_pay", b"arc_pay", "autoplay", b"autoplay", "bp", b"bp", "download", b"download", "elec", b"elec", "free_watch", b"free_watch", "hd5", b"hd5", "is_cooperation", b"is_cooperation", "movie", b"movie", "no_reprint", b"no_reprint", "pay", b"pay", "ugc_pay", b"ugc_pay", "ugc_pay_preview", b"ugc_pay_preview"]) -> None: ...

global___Rights = Rights

@typing_extensions.final
class SeasonEpisode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SECTION_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ARC_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    BADGE_STYLE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    section_id: builtins.int
    """"""
    id: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    title: builtins.str
    """"""
    attribute: builtins.int
    """"""
    @property
    def arc(self) -> global___Arc:
        """"""
    @property
    def page(self) -> global___Page:
        """"""
    bvid: builtins.str
    """"""
    @property
    def badge_style(self) -> global___ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        section_id: builtins.int = ...,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        title: builtins.str = ...,
        attribute: builtins.int = ...,
        arc: global___Arc | None = ...,
        page: global___Page | None = ...,
        bvid: builtins.str = ...,
        badge_style: global___ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "badge_style", b"badge_style", "page", b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "arc", b"arc", "attribute", b"attribute", "badge_style", b"badge_style", "bvid", b"bvid", "cid", b"cid", "id", b"id", "page", b"page", "season_id", b"season_id", "section_id", b"section_id", "title", b"title"]) -> None: ...

global___SeasonEpisode = SeasonEpisode

@typing_extensions.final
class SeasonSection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    type: builtins.int
    """"""
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SeasonEpisode]:
        """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        id: builtins.int = ...,
        title: builtins.str = ...,
        type: builtins.int = ...,
        episodes: collections.abc.Iterable[global___SeasonEpisode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes", b"episodes", "id", b"id", "season_id", b"season_id", "title", b"title", "type", b"type"]) -> None: ...

global___SeasonSection = SeasonSection

@typing_extensions.final
class SeasonStat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    view: builtins.int
    """"""
    danmaku: builtins.int
    """"""
    reply: builtins.int
    """"""
    fav: builtins.int
    """"""
    coin: builtins.int
    """"""
    share: builtins.int
    """"""
    now_rank: builtins.int
    """"""
    his_rank: builtins.int
    """"""
    like: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin", b"coin", "danmaku", b"danmaku", "fav", b"fav", "his_rank", b"his_rank", "like", b"like", "now_rank", b"now_rank", "reply", b"reply", "season_id", b"season_id", "share", b"share", "view", b"view"]) -> None: ...

global___SeasonStat = SeasonStat

@typing_extensions.final
class Space(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S_IMG_FIELD_NUMBER: builtins.int
    L_IMG_FIELD_NUMBER: builtins.int
    s_img: builtins.str
    """"""
    l_img: builtins.str
    """"""
    def __init__(
        self,
        *,
        s_img: builtins.str = ...,
        l_img: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["l_img", b"l_img", "s_img", b"s_img"]) -> None: ...

global___Space = Space

@typing_extensions.final
class Staff(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    LABEL_STYLE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    title: builtins.str
    """"""
    name: builtins.str
    """"""
    face: builtins.str
    """"""
    @property
    def vip(self) -> global___VipInfo:
        """"""
    @property
    def official(self) -> global___OfficialInfo:
        """"""
    follower: builtins.int
    """"""
    label_style: builtins.int
    """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        vip: global___VipInfo | None = ...,
        official: global___OfficialInfo | None = ...,
        follower: builtins.int = ...,
        label_style: builtins.int = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official", b"official", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "follower", b"follower", "label_style", b"label_style", "mid", b"mid", "name", b"name", "official", b"official", "relation", b"relation", "title", b"title", "vip", b"vip"]) -> None: ...

global___Staff = Staff

@typing_extensions.final
class StaffInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "title", b"title"]) -> None: ...

global___StaffInfo = StaffInfo

@typing_extensions.final
class Stat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    EVALUATION_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    view: builtins.int
    """"""
    danmaku: builtins.int
    """"""
    reply: builtins.int
    """"""
    fav: builtins.int
    """"""
    coin: builtins.int
    """"""
    share: builtins.int
    """"""
    now_rank: builtins.int
    """"""
    his_rank: builtins.int
    """"""
    like: builtins.int
    """"""
    dislike: builtins.int
    """"""
    evaluation: builtins.str
    """"""
    argue_msg: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
        evaluation: builtins.str = ...,
        argue_msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "argue_msg", b"argue_msg", "coin", b"coin", "danmaku", b"danmaku", "dislike", b"dislike", "evaluation", b"evaluation", "fav", b"fav", "his_rank", b"his_rank", "like", b"like", "now_rank", b"now_rank", "reply", b"reply", "share", b"share", "view", b"view"]) -> None: ...

global___Stat = Stat

@typing_extensions.final
class Subtitle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_SUBMIT_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    allow_submit: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubtitleItem]:
        """"""
    def __init__(
        self,
        *,
        allow_submit: builtins.bool = ...,
        list: collections.abc.Iterable[global___SubtitleItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_submit", b"allow_submit", "list", b"list"]) -> None: ...

global___Subtitle = Subtitle

@typing_extensions.final
class SubtitleItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    LAN_FIELD_NUMBER: builtins.int
    LAN_DOC_FIELD_NUMBER: builtins.int
    IS_LOCK_FIELD_NUMBER: builtins.int
    AUTHOR_MID_FIELD_NUMBER: builtins.int
    SUBTITLE_URL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    lan: builtins.str
    """"""
    lan_doc: builtins.str
    """"""
    is_lock: builtins.bool
    """"""
    author_mid: builtins.int
    """"""
    subtitle_url: builtins.str
    """"""
    @property
    def author(self) -> global___AccInfo:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        lan: builtins.str = ...,
        lan_doc: builtins.str = ...,
        is_lock: builtins.bool = ...,
        author_mid: builtins.int = ...,
        subtitle_url: builtins.str = ...,
        author: global___AccInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "author_mid", b"author_mid", "id", b"id", "is_lock", b"is_lock", "lan", b"lan", "lan_doc", b"lan_doc", "subtitle_url", b"subtitle_url"]) -> None: ...

global___SubtitleItem = SubtitleItem

@typing_extensions.final
class Tag(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    HEAD_COVER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    SHORT_CONTENT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    TAG_COUNT_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    HATES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    LIKED_FIELD_NUMBER: builtins.int
    HATED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    cover: builtins.str
    """"""
    head_cover: builtins.str
    """"""
    content: builtins.str
    """"""
    short_content: builtins.str
    """"""
    type: builtins.int
    """"""
    state: builtins.int
    """"""
    ctime: builtins.int
    """"""
    @property
    def tag_count(self) -> global___TagCount:
        """"""
    is_atten: builtins.int
    """"""
    likes: builtins.int
    """"""
    hates: builtins.int
    """"""
    attribute: builtins.int
    """"""
    liked: builtins.int
    """"""
    hated: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        cover: builtins.str = ...,
        head_cover: builtins.str = ...,
        content: builtins.str = ...,
        short_content: builtins.str = ...,
        type: builtins.int = ...,
        state: builtins.int = ...,
        ctime: builtins.int = ...,
        tag_count: global___TagCount | None = ...,
        is_atten: builtins.int = ...,
        likes: builtins.int = ...,
        hates: builtins.int = ...,
        attribute: builtins.int = ...,
        liked: builtins.int = ...,
        hated: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag_count", b"tag_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "content", b"content", "cover", b"cover", "ctime", b"ctime", "hated", b"hated", "hates", b"hates", "head_cover", b"head_cover", "id", b"id", "is_atten", b"is_atten", "liked", b"liked", "likes", b"likes", "name", b"name", "short_content", b"short_content", "state", b"state", "tag_count", b"tag_count", "type", b"type"]) -> None: ...

global___Tag = Tag

@typing_extensions.final
class TagCount(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    USE_FIELD_NUMBER: builtins.int
    ATTEN_FIELD_NUMBER: builtins.int
    view: builtins.int
    """"""
    use: builtins.int
    """"""
    atten: builtins.int
    """"""
    def __init__(
        self,
        *,
        view: builtins.int = ...,
        use: builtins.int = ...,
        atten: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["atten", b"atten", "use", b"use", "view", b"view"]) -> None: ...

global___TagCount = TagCount

@typing_extensions.final
class UGCPayAsset(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlatformPriceEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRICE_FIELD_NUMBER: builtins.int
    PLATFORM_PRICE_FIELD_NUMBER: builtins.int
    price: builtins.int
    """"""
    @property
    def platform_price(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        price: builtins.int = ...,
        platform_price: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["platform_price", b"platform_price", "price", b"price"]) -> None: ...

global___UGCPayAsset = UGCPayAsset

@typing_extensions.final
class UGCSeason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    SIGN_STATE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    EP_COUNT_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    IS_PAY_SEASON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    mid: builtins.int
    """"""
    intro: builtins.str
    """"""
    sign_state: builtins.int
    """"""
    attribute: builtins.int
    """"""
    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SeasonSection]:
        """"""
    @property
    def stat(self) -> global___SeasonStat:
        """"""
    ep_count: builtins.int
    """"""
    season_type: builtins.int
    """"""
    is_pay_season: builtins.bool
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        mid: builtins.int = ...,
        intro: builtins.str = ...,
        sign_state: builtins.int = ...,
        attribute: builtins.int = ...,
        sections: collections.abc.Iterable[global___SeasonSection] | None = ...,
        stat: global___SeasonStat | None = ...,
        ep_count: builtins.int = ...,
        season_type: builtins.int = ...,
        is_pay_season: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "cover", b"cover", "ep_count", b"ep_count", "id", b"id", "intro", b"intro", "is_pay_season", b"is_pay_season", "mid", b"mid", "season_type", b"season_type", "sections", b"sections", "sign_state", b"sign_state", "stat", b"stat", "title", b"title"]) -> None: ...

global___UGCSeason = UGCSeason

@typing_extensions.final
class View(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    NO_CACHE_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    STEIN_GUIDE_CID_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
    no_cache: builtins.bool
    """"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
    @property
    def subtitle(self) -> global___Subtitle:
        """"""
    @property
    def asset(self) -> global___UGCPayAsset:
        """"""
    @property
    def label(self) -> global___ViewLabel:
        """"""
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
    @property
    def ugc_season(self) -> global___UGCSeason:
        """"""
    stein_guide_cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        arc: global___Arc | None = ...,
        no_cache: builtins.bool = ...,
        pages: collections.abc.Iterable[global___Page] | None = ...,
        subtitle: global___Subtitle | None = ...,
        asset: global___UGCPayAsset | None = ...,
        label: global___ViewLabel | None = ...,
        staff: collections.abc.Iterable[global___Staff] | None = ...,
        ugc_season: global___UGCSeason | None = ...,
        stein_guide_cid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "asset", b"asset", "label", b"label", "subtitle", b"subtitle", "ugc_season", b"ugc_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "asset", b"asset", "label", b"label", "no_cache", b"no_cache", "pages", b"pages", "staff", b"staff", "stein_guide_cid", b"stein_guide_cid", "subtitle", b"subtitle", "ugc_season", b"ugc_season"]) -> None: ...

global___View = View

@typing_extensions.final
class ViewDetailReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    CARD_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    RELATED_FIELD_NUMBER: builtins.int
    @property
    def view(self) -> global___View:
        """"""
    @property
    def card(self) -> global___Card:
        """"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """"""
    @property
    def reply(self) -> global___HotReply:
        """"""
    @property
    def related(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Arc]:
        """"""
    def __init__(
        self,
        *,
        view: global___View | None = ...,
        card: global___Card | None = ...,
        tags: collections.abc.Iterable[global___Tag] | None = ...,
        reply: global___HotReply | None = ...,
        related: collections.abc.Iterable[global___Arc] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card", b"card", "reply", b"reply", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card", b"card", "related", b"related", "reply", b"reply", "tags", b"tags", "view", b"view"]) -> None: ...

global___ViewDetailReply = ViewDetailReply

@typing_extensions.final
class ViewDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid"]) -> None: ...

global___ViewDetailReq = ViewDetailReq

@typing_extensions.final
class ViewLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ViewLabel = ViewLabel

@typing_extensions.final
class VipInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    status: builtins.int
    """"""
    vip_pay_type: builtins.int
    """"""
    theme_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        status: builtins.int = ...,
        vip_pay_type: builtins.int = ...,
        theme_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "theme_type", b"theme_type", "type", b"type", "vip_pay_type", b"vip_pay_type"]) -> None: ...

global___VipInfo = VipInfo

@typing_extensions.final
class VipLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    """"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___VipLabel = VipLabel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/show/mixture/v1/mixture.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/app/show/mixture/v1/mixture.proto\x12\x1c\x62ilibili.app.show.mixture.v1\"2\n\nRcmdReason\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x13\n\x0b\x63orner_mark\x18\x02 \x01(\r\"\xbf\x01\n\nWidgetItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0c\n\x04view\x18\x02 \x01(\t\x12=\n\x0brcmd_reason\x18\x03 \x01(\x0b\x32(.bilibili.app.show.mixture.v1.RcmdReason\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x0c\n\x04goto\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\x03\x12\x11\n\tview_icon\x18\t \x01(\x05\"E\n\x0bWidgetReply\x12\x36\n\x04item\x18\x01 \x03(\x0b\x32(.bilibili.app.show.mixture.v1.WidgetItem\"0\n\tWidgetReq\x12\x12\n\nfrom_spmid\x18\x01 \x01(\t\x12\x0f\n\x07page_no\x18\x02 \x01(\r2g\n\x07Mixture\x12\\\n\x06Widget\x12\'.bilibili.app.show.mixture.v1.WidgetReq\x1a).bilibili.app.show.mixture.v1.WidgetReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.mixture.v1.mixture_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RCMDREASON']._serialized_start=76
  _globals['_RCMDREASON']._serialized_end=126
  _globals['_WIDGETITEM']._serialized_start=129
  _globals['_WIDGETITEM']._serialized_end=320
  _globals['_WIDGETREPLY']._serialized_start=322
  _globals['_WIDGETREPLY']._serialized_end=391
  _globals['_WIDGETREQ']._serialized_start=393
  _globals['_WIDGETREQ']._serialized_end=441
  _globals['_MIXTURE']._serialized_start=443
  _globals['_MIXTURE']._serialized_end=546
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dagw/component/avatar/common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2bilibili/dagw/component/avatar/common/common.proto\x12%bilibili.dagw.component.avatar.common\"\"\n\x0f\x42\x61sicRenderSpec\x12\x0f\n\x07opacity\x18\x01 \x01(\x01\"\xa9\x01\n\x0b\x43olorConfig\x12\x1a\n\x12is_dark_mode_aware\x18\x01 \x01(\x08\x12=\n\x03\x64\x61y\x18\x02 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.ColorSpec\x12?\n\x05night\x18\x03 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.ColorSpec\"\x19\n\tColorSpec\x12\x0c\n\x04\x61rgb\x18\x01 \x01(\t\"\xea\x01\n\x10LayerGeneralSpec\x12\x45\n\x08pos_spec\x18\x01 \x01(\x0b\x32\x33.bilibili.dagw.component.avatar.common.PositionSpec\x12\x42\n\tsize_spec\x18\x02 \x01(\x0b\x32/.bilibili.dagw.component.avatar.common.SizeSpec\x12K\n\x0brender_spec\x18\x03 \x01(\x0b\x32\x36.bilibili.dagw.component.avatar.common.BasicRenderSpec\"\xa6\x01\n\x0cMaskProperty\x12M\n\x0cgeneral_spec\x18\x01 \x01(\x0b\x32\x37.bilibili.dagw.component.avatar.common.LayerGeneralSpec\x12G\n\x08mask_src\x18\x02 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.common.ResourceSource\"\x94\x01\n\rNativeDrawRes\x12\x11\n\tdraw_type\x18\x01 \x01(\x05\x12\x11\n\tfill_mode\x18\x02 \x01(\x05\x12H\n\x0c\x63olor_config\x18\x03 \x01(\x0b\x32\x32.bilibili.dagw.component.avatar.common.ColorConfig\x12\x13\n\x0b\x65\x64ge_weight\x18\x04 \x01(\x01\"F\n\x0cPositionSpec\x12\x16\n\x0e\x63oordinate_pos\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_x\x18\x02 \x01(\x01\x12\x0e\n\x06\x61xis_y\x18\x03 \x01(\x01\"+\n\tRemoteRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tbfs_style\x18\x02 \x01(\t\"\xfc\x03\n\x0eResourceSource\x12\x10\n\x08src_type\x18\x01 \x01(\x05\x12\x13\n\x0bplaceholder\x18\x02 \x01(\x05\x12\x42\n\x06remote\x18\x03 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.RemoteResH\x00\x12O\n\x05local\x18\x04 \x01(\x0e\x32>.bilibili.dagw.component.avatar.common.ResourceSource.LocalResH\x00\x12\x44\n\x04\x64raw\x18\x05 \x01(\x0b\x32\x34.bilibili.dagw.component.avatar.common.NativeDrawResH\x00\"\xe0\x01\n\x08LocalRes\x12\x15\n\x11LOCAL_RES_INVALID\x10\x00\x12\x16\n\x12LOCAL_RES_ICON_VIP\x10\x01\x12\x1c\n\x18LOCAL_RES_ICON_SMALL_VIP\x10\x02\x12\"\n\x1eLOCAL_RES_ICON_PERSONAL_VERIFY\x10\x03\x12$\n LOCAL_RES_ICON_ENTERPRISE_VERIFY\x10\x04\x12\x1f\n\x1bLOCAL_RES_ICON_NFT_MAINLAND\x10\x05\x12\x1c\n\x18LOCAL_RES_DEFAULT_AVATAR\x10\x06\x42\x05\n\x03res\")\n\x08SizeSpec\x12\r\n\x05width\x18\x01 \x01(\x01\x12\x0e\n\x06height\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dagw.component.avatar.common.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICRENDERSPEC']._serialized_start=93
  _globals['_BASICRENDERSPEC']._serialized_end=127
  _globals['_COLORCONFIG']._serialized_start=130
  _globals['_COLORCONFIG']._serialized_end=299
  _globals['_COLORSPEC']._serialized_start=301
  _globals['_COLORSPEC']._serialized_end=326
  _globals['_LAYERGENERALSPEC']._serialized_start=329
  _globals['_LAYERGENERALSPEC']._serialized_end=563
  _globals['_MASKPROPERTY']._serialized_start=566
  _globals['_MASKPROPERTY']._serialized_end=732
  _globals['_NATIVEDRAWRES']._serialized_start=735
  _globals['_NATIVEDRAWRES']._serialized_end=883
  _globals['_POSITIONSPEC']._serialized_start=885
  _globals['_POSITIONSPEC']._serialized_end=955
  _globals['_REMOTERES']._serialized_start=957
  _globals['_REMOTERES']._serialized_end=1000
  _globals['_RESOURCESOURCE']._serialized_start=1003
  _globals['_RESOURCESOURCE']._serialized_end=1511
  _globals['_RESOURCESOURCE_LOCALRES']._serialized_start=1280
  _globals['_RESOURCESOURCE_LOCALRES']._serialized_end=1504
  _globals['_SIZESPEC']._serialized_start=1513
  _globals['_SIZESPEC']._serialized_end=1554
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AtSearchReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """可以为 1 , 但是不能为 0 或空 不知道有啥用"""
    keyword: builtins.str
    """用户名搜索关键词"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        keyword: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "mid", b"mid"]) -> None: ...

global___AtSearchReq = AtSearchReq

@typing_extensions.final
class AtSearchReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtGroup]:
        """搜索结果分组"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___AtGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___AtSearchReply = AtSearchReply

@typing_extensions.final
class AtGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_TYPE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    group_type: builtins.int
    """分组类型  2: 我的关注 4:其他 ,其他自测"""
    group_name: builtins.str
    """分组名称"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtItem]:
        """用户列表"""
    def __init__(
        self,
        *,
        group_type: builtins.int = ...,
        group_name: builtins.str = ...,
        items: collections.abc.Iterable[global___AtItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name", b"group_name", "group_type", b"group_type", "items", b"items"]) -> None: ...

global___AtGroup = AtGroup

@typing_extensions.final
class AtItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    name: builtins.str
    face: builtins.str
    fans: builtins.int
    official_verify_type: builtins.int
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        fans: builtins.int = ...,
        official_verify_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "fans", b"fans", "mid", b"mid", "name", b"name", "official_verify_type", b"official_verify_type"]) -> None: ...

global___AtItem = AtItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetOnlineRankReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUID_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    ruid: builtins.int
    """"""
    room_id: builtins.int
    """"""
    page: builtins.int
    """"""
    page_size: builtins.int
    """"""
    platform: builtins.str
    """"""
    def __init__(
        self,
        *,
        ruid: builtins.int = ...,
        room_id: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        platform: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "page_size", b"page_size", "platform", b"platform", "room_id", b"room_id", "ruid", b"ruid"]) -> None: ...

global___GetOnlineRankReq = GetOnlineRankReq

@typing_extensions.final
class GetOnlineRankResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OnlineRankItem(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UID_FIELD_NUMBER: builtins.int
        UNAME_FIELD_NUMBER: builtins.int
        FACE_FIELD_NUMBER: builtins.int
        CONTINUE_WATCH_FIELD_NUMBER: builtins.int
        MEDAL_INFO_FIELD_NUMBER: builtins.int
        GUARD_LEVEL_FIELD_NUMBER: builtins.int
        uid: builtins.int
        """"""
        uname: builtins.str
        """"""
        face: builtins.str
        """"""
        continue_watch: builtins.int
        """"""
        @property
        def medal_info(self) -> global___MedalInfo:
            """"""
        guard_level: builtins.int
        """"""
        def __init__(
            self,
            *,
            uid: builtins.int = ...,
            uname: builtins.str = ...,
            face: builtins.str = ...,
            continue_watch: builtins.int = ...,
            medal_info: global___MedalInfo | None = ...,
            guard_level: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["medal_info", b"medal_info"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["continue_watch", b"continue_watch", "face", b"face", "guard_level", b"guard_level", "medal_info", b"medal_info", "uid", b"uid", "uname", b"uname"]) -> None: ...

    ITEM_FIELD_NUMBER: builtins.int
    ONLINE_NUM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___GetOnlineRankResp.OnlineRankItem:
        """"""
    online_num: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___GetOnlineRankResp.OnlineRankItem | None = ...,
        online_num: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "online_num", b"online_num"]) -> None: ...

global___GetOnlineRankResp = GetOnlineRankResp

@typing_extensions.final
class MedalInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GUARD_LEVEL_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_START_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_END_FIELD_NUMBER: builtins.int
    MEDAL_COLOR_BORDER_FIELD_NUMBER: builtins.int
    MEDAL_NAME_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    IS_LIGHT_FIELD_NUMBER: builtins.int
    guard_level: builtins.int
    """"""
    medal_color_start: builtins.int
    """"""
    medal_color_end: builtins.int
    """"""
    medal_color_border: builtins.int
    """"""
    medal_name: builtins.str
    """"""
    level: builtins.int
    """"""
    target_id: builtins.int
    """"""
    is_light: builtins.int
    """"""
    def __init__(
        self,
        *,
        guard_level: builtins.int = ...,
        medal_color_start: builtins.int = ...,
        medal_color_end: builtins.int = ...,
        medal_color_border: builtins.int = ...,
        medal_name: builtins.str = ...,
        level: builtins.int = ...,
        target_id: builtins.int = ...,
        is_light: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guard_level", b"guard_level", "is_light", b"is_light", "level", b"level", "medal_color_border", b"medal_color_border", "medal_color_end", b"medal_color_end", "medal_color_start", b"medal_color_start", "medal_name", b"medal_name", "target_id", b"target_id"]) -> None: ...

global___MedalInfo = MedalInfo
